import { Context } from '../../../context';
import * as Inputs from '../../../inputs/inputs';
import { Base } from '../../../inputs/inputs';
import { BabylonArcRotateCamera } from './arc-rotate-camera';
import { BabylonFreeCamera } from './free-camera';
import { BabylonTargetCamera } from './target-camera';
export declare class BabylonCamera {
    private readonly context;
    free: BabylonFreeCamera;
    arcRotate: BabylonArcRotateCamera;
    target: BabylonTargetCamera;
    constructor(context: Context);
    /**
     * Freeze projection matrix of the camera
     * @param inputs Camera to freeze
     */
    freezeProjectionMatrix(inputs: Inputs.BabylonCamera.CameraDto): void;
    /**
     * Unfreeze projection matrix of the camera
     * @param inputs Camera to freeze
     */
    unfreezeProjectionMatrix(inputs: Inputs.BabylonCamera.CameraDto): void;
    /**
     * Changes the position of a camera
     * @param inputs Changes the camera position
     */
    setPosition(inputs: Inputs.BabylonCamera.PositionDto): void;
    /**
     * Gets the position of a camera
     * @param inputs Gets the camera position
     */
    getPosition(inputs: Inputs.BabylonCamera.PositionDto): Base.Point3;
    /**
     * Changes the target of a camera
     * @param inputs Changes the camera target
     */
    setTarget(inputs: Inputs.BabylonCamera.TargetDto): void;
    /**
     * Gets the target of a camera
     * @param inputs Gets the camera position
     */
    getTarget(inputs: Inputs.BabylonCamera.PositionDto): Base.Point3;
    /**
     * Changes the speed of a camera
     * @param inputs Changes the camera target
     */
    setSpeed(inputs: Inputs.BabylonCamera.SpeedDto): void;
    /**
     * Gets the speed of a camera
     * @param inputs Gets the camera position
     */
    getSpeed(inputs: Inputs.BabylonCamera.PositionDto): Base.Point3;
    /**
     * Changes the minZ of a camera
     * @param inputs Changes the camera minZ
     */
    setMinZ(inputs: Inputs.BabylonCamera.MinZDto): void;
    /**
     * Changes the maxZ of a camera
     * @param inputs Changes the camera maxZ
     */
    setMaxZ(inputs: Inputs.BabylonCamera.MaxZDto): void;
}
