import { Vector3 } from '@babylonjs/core';
import { BabylonArcRotateCamera } from './arc-rotate-camera';
import { BabylonFreeCamera } from './free-camera';
import { BabylonTargetCamera } from './target-camera';
export class BabylonCamera {
    constructor(context) {
        this.context = context;
        this.free = new BabylonFreeCamera(this.context);
        this.arcRotate = new BabylonArcRotateCamera(this.context);
        this.target = new BabylonTargetCamera(this.context);
    }
    /**
     * Freeze projection matrix of the camera
     * @param inputs Camera to freeze
     */
    freezeProjectionMatrix(inputs) {
        inputs.camera.freezeProjectionMatrix();
    }
    /**
     * Unfreeze projection matrix of the camera
     * @param inputs Camera to freeze
     */
    unfreezeProjectionMatrix(inputs) {
        inputs.camera.unfreezeProjectionMatrix();
    }
    /**
     * Changes the position of a camera
     * @param inputs Changes the camera position
     */
    setPosition(inputs) {
        const pos = new Vector3(inputs.position[0], inputs.position[1], inputs.position[2]);
        inputs.camera.position = pos;
    }
    /**
     * Gets the position of a camera
     * @param inputs Gets the camera position
     */
    getPosition(inputs) {
        return [inputs.camera.position.x, inputs.camera.position.y, inputs.camera.position.z];
    }
    /**
     * Changes the target of a camera
     * @param inputs Changes the camera target
     */
    setTarget(inputs) {
        const target = new Vector3(inputs.target[0], inputs.target[1], inputs.target[2]);
        inputs.camera.setTarget(target);
    }
    /**
     * Gets the target of a camera
     * @param inputs Gets the camera position
     */
    getTarget(inputs) {
        return [inputs.camera.target.x, inputs.camera.target.y, inputs.camera.target.z];
    }
    /**
     * Changes the speed of a camera
     * @param inputs Changes the camera target
     */
    setSpeed(inputs) {
        inputs.camera.speed = inputs.speed;
    }
    /**
     * Gets the speed of a camera
     * @param inputs Gets the camera position
     */
    getSpeed(inputs) {
        return [inputs.camera.target.x, inputs.camera.target.y, inputs.camera.target.z];
    }
    /**
     * Changes the minZ of a camera
     * @param inputs Changes the camera minZ
     */
    setMinZ(inputs) {
        inputs.camera.minZ = inputs.minZ;
    }
    /**
     * Changes the maxZ of a camera
     * @param inputs Changes the camera maxZ
     */
    setMaxZ(inputs) {
        inputs.camera.maxZ = inputs.maxZ;
    }
}
