import { Context } from '../../../context';
import { PBRMetallicRoughnessMaterial } from '@babylonjs/core';
import * as Inputs from '../../../inputs/inputs';
import { Color } from '../../color';
export declare class BabylonMaterialPbrMetallicRoughness {
    private readonly context;
    private readonly color;
    constructor(context: Context, color: Color);
    /**
     * Create PBR metallic roughnes material.
     * @param inputs required to set up metallic roughness material
     * @returns PBR metallic roughness material
     * @group create
     * @shortname material
     * @disposableOutput true
     */
    create(inputs: Inputs.BabylonMaterial.PBRMetallicRoughnessDto): PBRMetallicRoughnessMaterial;
    /**
     * Sets the base color of material
     * @param inputs base color and material
     * @group set
     * @shortname base color
     */
    setBaseColor(inputs: Inputs.BabylonMaterial.BaseColorDto): void;
    /**
     * Sets the metallic property of material
     * @param inputs metallic value
     * @group set
     * @shortname metallic
     */
    setMetallic(inputs: Inputs.BabylonMaterial.MetallicDto): void;
    /**
     * Sets the roughness of material
     * @param inputs roughness value
     * @group set
     * @shortname roughness
     */
    setRoughness(inputs: Inputs.BabylonMaterial.RoughnessDto): void;
    /**
     * Sets the alpha of material
     * @param inputs alpha value
     * @group set
     * @shortname alpha
     */
    setAlpha(inputs: Inputs.BabylonMaterial.AlphaDto): void;
    /**
     * Sets the back face culling of material
     * @param inputs back face culling boolean
     * @group set
     * @shortname back face culling
     */
    setBackFaceCulling(inputs: Inputs.BabylonMaterial.BackFaceCullingDto): void;
    /**
     * Gets the base color of material
     * @param inputs base color and material
     * @return base color
     * @group get
     * @shortname base color
     */
    getBaseColor(inputs: Inputs.BabylonMaterial.MaterialPropDto): string;
    /**
     * Gets the metallic property of material
     * @param inputs metallic value
     * @return metallic value
     * @group get
     * @shortname metallic
     */
    getMetallic(inputs: Inputs.BabylonMaterial.MaterialPropDto): number;
    /**
     * Gets the roughness of material
     * @param inputs roughness value
     * @return roughness value
     * @group get
     * @shortname roughness
     */
    getRoughness(inputs: Inputs.BabylonMaterial.MaterialPropDto): number;
    /**
     * Gets the alpha of material
     * @param inputs alpha value
     * @return alpha value
     * @group get
     * @shortname alpha
     */
    getAlpha(inputs: Inputs.BabylonMaterial.MaterialPropDto): number;
    /**
     * Gets the back face culling of material
     * @param inputs back face culling boolean
     * @return backfaceculling boolean
     * @group get
     * @shortname back face culling
     */
    getBackFaceCulling(inputs: Inputs.BabylonMaterial.MaterialPropDto): boolean;
}
