import { Context } from '../../context';
import { PickingInfo, AbstractMesh, Sprite } from '@babylonjs/core';
import * as Inputs from '../../inputs/inputs';
import { Base } from '../../inputs/inputs';
export declare class BabylonPick {
    private readonly context;
    constructor(context: Context);
    /**
     * Get a hit result of picking with ray
     * @param inputs ray to use for picking
     * @returns Picking info
     */
    pickWithRay(inputs: Inputs.BabylonPick.RayDto): PickingInfo;
    /**
     * Pick with picking ray of the current mouse position in the active camera
     * @returns Picking info
     */
    pickWithPickingRay(): PickingInfo;
    /**
     * Get the distance to the object if picking result exists
     * @param inputs picking result
     * @returns Distance
     */
    getDistance(inputs: Inputs.BabylonPick.PickInfo): number;
    /**
     * Get the picked mesh
     * @param inputs picking result
     * @returns Picked mesh
     */
    getPickedMesh(inputs: Inputs.BabylonPick.PickInfo): AbstractMesh;
    /**
     * Get the picked point
     * @param inputs picking result
     * @returns Picked point
     */
    getPickedPoint(inputs: Inputs.BabylonPick.PickInfo): Base.Point3;
    /**
     * Check if pick ray hit something in the scene or not
     * @param inputs picking result
     * @returns Indication of a hit
     */
    hit(inputs: Inputs.BabylonPick.PickInfo): boolean;
    /**
     * Gets the unique submesh id if it was picked
     * @param inputs picking result
     * @returns Submesh id
     */
    getSubMeshId(inputs: Inputs.BabylonPick.PickInfo): number;
    /**
     * Gets the unique submesh face id if it was picked
     * @param inputs picking result
     * @returns Submesh face id
     */
    getSubMeshFaceId(inputs: Inputs.BabylonPick.PickInfo): number;
    /**
     * Gets the the barycentric U coordinate that is used when calculating the texture coordinates of the collision
     * @param inputs picking result
     * @returns U coordinate
     */
    getBU(inputs: Inputs.BabylonPick.PickInfo): number;
    /**
     * Gets the the barycentric V coordinate that is used when calculating the texture coordinates of the collision
     * @param inputs picking result
     * @returns V coordinate
     */
    getBV(inputs: Inputs.BabylonPick.PickInfo): number;
    /**
     * Get the picked sprite
     * @param inputs picking result
     * @returns Picked sprite
     */
    getPickedSprite(inputs: Inputs.BabylonPick.PickInfo): Sprite;
}
