import { Context } from '../../context';
import { Ray } from '@babylonjs/core';
import * as Inputs from '../../inputs/inputs';
import { Base } from '../../inputs/inputs';
export declare class BabylonRay {
    private readonly context;
    constructor(context: Context);
    /**
     * Creates a picking ray of the current mouse position in the active camera
     * @returns Ray
     */
    createPickingRay(): Ray;
    /**
     * Create a ray that start at origin, has direction vector and optionally length
     * @param inputs origin, direction and length
     * @returns ray
     */
    createRay(inputs: Inputs.BabylonRay.BaseRayDto): Ray;
    /**
     * Create a ray from one point to another
     * @param inputs origin, direction and length
     * @returns ray
     */
    createRayFromTo(inputs: Inputs.BabylonRay.FromToDto): Ray;
    /**
     * Get the origin of the ray
     * @param inputs ray
     * @returns origin point
     */
    getOrigin(inputs: Inputs.BabylonRay.RayDto): Base.Point3;
    /**
     * Get the direction of the ray
     * @param inputs ray
     * @returns direction vector
     */
    getDirection(inputs: Inputs.BabylonRay.RayDto): Base.Vector3;
    /**
     * Get the length of the ray
     * @param inputs ray
     * @returns length
     */
    getLength(inputs: Inputs.BabylonRay.RayDto): number;
}
