var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Color3, PBRMetallicRoughnessMaterial, WebXRFeatureName } from '@babylonjs/core';
import { GUI3DManager, NearMenu, TextBlock, TouchHolographicButton } from '@babylonjs/gui';
export class BabylonWebXR {
    constructor(context) {
        this.context = context;
    }
    /**
     * Creates default XR experience with teleportation
     * @param inputs Creates default XR experience with teleportation
     */
    createDefaultXRExperienceWithTeleportation(inputs) {
        return __awaiter(this, void 0, void 0, function* () {
            const xr = yield this.context.scene.createDefaultXRExperienceAsync();
            if (this.context.scene.metadata) {
                this.context.scene.metadata.xr = xr;
            }
            else {
                this.context.scene.metadata = { xr };
            }
            const meshes = [];
            inputs.groundMeshes.forEach(m => {
                if (m.getChildMeshes) {
                    m === null || m === void 0 ? void 0 : m.getChildMeshes().forEach(cm => {
                        cm.isPickable = true;
                        meshes.push(cm);
                    });
                }
                meshes.push(m);
                m.isPickable = true;
            });
            const featuresManager = xr.baseExperience.featuresManager;
            const torusMat = new PBRMetallicRoughnessMaterial('teleportation');
            torusMat.baseColor = new Color3(0, 0, 1);
            torusMat.metallic = 0;
            torusMat.roughness = 1;
            featuresManager.enableFeature(WebXRFeatureName.TELEPORTATION, 'stable', {
                xrInput: xr.input,
                floorMeshes: meshes,
                defaultTargetMeshOptions: {
                    torusArrowMaterial: torusMat,
                    disableLighting: false,
                },
            });
            const manager = new GUI3DManager(this.context.scene);
            this.context.scene.metadata.guiManager = manager;
            manager.useRealisticScaling = true;
            const near = new NearMenu('near');
            manager.addControl(near);
            const button1 = new TouchHolographicButton('button1');
            const text = new TextBlock();
            text.text = 'Exit VR';
            text.color = 'white';
            text.fontSize = '48px';
            button1.onPointerClickObservable.add(() => __awaiter(this, void 0, void 0, function* () {
                yield xr.baseExperience.exitXRAsync();
            }));
            near.addButton(button1);
            button1.content = text;
        });
    }
}
