import { Mesh } from '@babylonjs/core';
import * as Inputs from '../inputs/inputs';
import { Point } from './point';
import { Line } from './line';
import { Polyline } from './polyline';
import { BabylonNode } from './babylon/node';
import { VerbCurve } from './verb/curve';
import { VerbSurface } from './verb/surface';
import { JSCAD } from './jscad/jscad';
import { OCCTW } from './occt/occt';
import { Tag } from './tag';
import { Context } from '../context';
export declare class Draw {
    /**
     * @ignore true
     */
    readonly point: Point;
    /**
     * @ignore true
     */
    readonly line: Line;
    /**
     * @ignore true
     */
    readonly polyline: Polyline;
    /**
     * @ignore true
     */
    readonly node: BabylonNode;
    /**
     * @ignore true
     */
    readonly verbCurve: VerbCurve;
    /**
     * @ignore true
     */
    readonly verbSurface: VerbSurface;
    /**
     * @ignore true
     */
    readonly jscad: JSCAD;
    /**
     * @ignore true
     */
    readonly occt: OCCTW;
    /**
     * @ignore true
     */
    readonly tag: Tag;
    /**
     * @ignore true
     */
    readonly context: Context;
    private defaultBasicOptions;
    private defaultNodeOptions;
    constructor(
    /**
     * @ignore true
     */
    point: Point, 
    /**
     * @ignore true
     */
    line: Line, 
    /**
     * @ignore true
     */
    polyline: Polyline, 
    /**
     * @ignore true
     */
    node: BabylonNode, 
    /**
     * @ignore true
     */
    verbCurve: VerbCurve, 
    /**
     * @ignore true
     */
    verbSurface: VerbSurface, 
    /**
     * @ignore true
     */
    jscad: JSCAD, 
    /**
     * @ignore true
     */
    occt: OCCTW, 
    /**
     * @ignore true
     */
    tag: Tag, 
    /**
     * @ignore true
     */
    context: Context);
    /**
     * Draws any kind of geometry after all input promises are resolved. Inputs can also be non-promise like.
     * @param inputs Contains options and entities to be drawn
     * @returns BabylonJS Mesh Promise
     * @group draw
     * @shortname draw anything
     * @disposableOutput true
     */
    drawAnyAsync(inputs: Inputs.Draw.DrawAny): Promise<Mesh>;
    private updateAny;
    /**
     * Draws a grid mesh on the ground plane in 3D space. This helps to orient yourself in the world.
     * @param inputs Describes various parameters of the grid mesh like size, colour, etc.
     * @group draw
     * @shortname draw grid
     * @disposableOutput true
     */
    drawGridMesh(inputs: Inputs.Draw.SceneDrawGridMeshDto): Mesh;
    /**
     * Draws any kind of geometry. Inputs can not be promises.
     * @param inputs Contains options and entities to be drawn
     * @returns BabylonJS Mesh
     */
    private drawAny;
    /**
     * Creates draw options for basic geometry types like points, lines, polylines, surfaces and jscad meshes
     * @param inputs option definition
     * @returns options
     * @group options
     * @shortname simple
     */
    optionsSimple(inputs: Inputs.Draw.DrawBasicGeometryOptions): Inputs.Draw.DrawBasicGeometryOptions;
    /**
     * Creates draw options for occt shape geometry like edges, wires, faces, shells, solids and compounds
     * @param inputs option definition
     * @returns options
     * @group options
     * @shortname occt shape
     */
    optionsOcctShape(inputs: Inputs.Draw.DrawOcctShapeOptions): Inputs.Draw.DrawOcctShapeOptions;
    /**
     * Creates draw options for babylon js nodes
     * @param inputs option definition
     * @returns options
     * @group options
     * @shortname babylon node
     */
    optionsBabylonNode(inputs: Inputs.Draw.DrawNodeOptions): Inputs.Draw.DrawNodeOptions;
    private handleTags;
    private handleTag;
    private handleVerbSurfaces;
    private handleVerbCurves;
    private handleNodes;
    private handlePoints;
    private handleLines;
    private handlePolylines;
    private handleVerbSurface;
    private handleVerbCurve;
    private handleNode;
    private handlePolyline;
    private handlePoint;
    private handleLine;
    private handleJscadMeshes;
    private handleOcctShape;
    private handleJscadMesh;
    private applyGlobalSettingsAndMetadataAndShadowCasting;
    private detectPoint;
    private detectPoints;
    private detectLine;
    private detectLines;
    private detectPolyline;
    private detectPolylines;
    private detectNode;
    private detectNodes;
    private detectVerbCurve;
    private detectVerbSurface;
    private detectVerbCurves;
    private detectVerbSurfaces;
    private detectJscadMesh;
    private detectJscadMeshes;
    private detectOcctShape;
    private detectTag;
    private detectTags;
    private checkIfElementsInArrayAreNumbers;
    private checkIfElementsInArrayAreArrays;
    private arraysInChildrenArraysContainNumbers;
    private arraysInChildrenArraysAreOfLength3;
}
