import * as Inputs from '../inputs/inputs';
/**
 * Contains various list methods.
 * <div>
 *  <img src="../assets/images/blockly-images/math/math.svg" alt="Blockly Image"/>
 * </div>
 */
export declare class Lists {
    constructor();
    /**
     * Gets an item from the list by using a 0 based index
     * @param inputs a list and an index
     * @returns item
     * @group get
     * @shortname item by index
     * @drawable false
     */
    getItem(inputs: Inputs.Lists.ListItemDto): any;
    /**
       * Gets a sub list between start and end indexes
       * @param inputs a list and start and end indexes
       * @returns sub list
       * @group get
       * @shortname sublist
       * @drawable false
       */
    getSubList(inputs: Inputs.Lists.SubListDto): any;
    /**
     * Gets nth item in the list
     * @param inputs a list and index
     * @returns list with removed item
     * @group get
     * @shortname every n-th
     * @drawable false
     */
    getNthItem(inputs: Inputs.Lists.GetNthItemDto): any;
    /**
     * Gets elements by pattern
     * @param inputs a list and index
     * @returns list with removed item
     * @group get
     * @shortname by pattern
     * @drawable false
     */
    getByPattern(inputs: Inputs.Lists.GetByPatternDto): any;
    /**
     * Merge elements of lists on a given level and flatten output if needed
     * @param inputs lists, level and flatten data
     * @returns list with merged lists and flattened lists
     * @group get
     * @shortname merge levels
     * @drawable false
     */
    mergeElementsOfLists(inputs: Inputs.Lists.MergeElementsOfLists): any;
    /**
     * Gets the longest list length from the list of lists
     * @param inputs a list of lists
     * @returns number of max length
     * @group get
     * @shortname longest list length
     * @drawable false
     */
    getLongestListLength(inputs: Inputs.Lists.GetLongestListLength): number;
    /**
     * Reverse the list
     * @param inputs a list and an index
     * @returns item
     * @group edit
     * @shortname reverse
     * @drawable false
     */
    reverse(inputs: Inputs.Lists.ListDto): any;
    /**
     * Flip 2d lists - every nth element of each list will form a separate list
     * @param inputs a list of lists to flip
     * @returns item
     * @group edit
     * @shortname flip lists
     * @drawable false
     */
    flipLists(inputs: Inputs.Lists.ListDto): any;
    /**
     * Group in lists of n elements
     * @param inputs a list
     * @returns items grouped in lists of n elements
     * @group edit
     * @shortname group elements
     * @drawable false
     */
    groupNth(inputs: Inputs.Lists.GroupListDto): any;
    /**
     * Get the depth of the list
     * @param inputs a list
     * @returns number of depth
     * @group get
     * @shortname max list depth
     * @drawable false
     */
    getListDepth(inputs: Inputs.Lists.ListDto): number;
    /**
     * Gets the length of the list
     * @param inputs a length list
     * @returns a number
     * @group get
     * @shortname list length
     * @drawable false
     */
    listLength(inputs: Inputs.Lists.ListDto): number;
    /**
     * Add item to the list
     * @param inputs a list, item and an index
     * @returns list with added item
     * @group add
     * @shortname item at index
     * @drawable false
     */
    addItemAtIndex(inputs: Inputs.Lists.AddItemAtIndexDto): any;
    /**
     * Adds item to the list of provided indexes
     * @param inputs a list, item and an indexes
     * @returns list with added item
     * @group add
     * @shortname item at indexes
     * @drawable false
     */
    addItemAtIndexes(inputs: Inputs.Lists.AddItemAtIndexesDto): any;
    /**
     * Adds items to the list of provided indexes matching 1:1, first item will go to first index provided, etc.
     * @param inputs a list, items and an indexes
     * @returns list with added items
     * @group add
     * @shortname items at indexes
     * @drawable false
     */
    addItemsAtIndexes(inputs: Inputs.Lists.AddItemsAtIndexesDto): any;
    /**
     * Remove item from the list
     * @param inputs a list and index
     * @returns list with removed item
     * @group remove
     * @shortname item at index
     * @drawable false
     */
    removeItemAtIndex(inputs: Inputs.Lists.RemoveItemAtIndexDto): any;
    /**
     * Remove item from the list
     * @param inputs a list and index
     * @returns list with removed item
     * @group remove
     * @shortname every n-th
     * @drawable false
     */
    removeNthItem(inputs: Inputs.Lists.RemoveNthItemDto): any;
    /**
     * Add item to the beginning or the end of the list
     * @param inputs a list, item and an option for first or last position
     * @returns list with added item
     * @group add
     * @shortname item at first or last
     * @drawable false
     */
    addItemFirstLast(inputs: Inputs.Lists.AddItemFirstLastDto): any;
    /**
     * Creates an empty list
     * @returns an empty array list
     * @group create
     * @shortname empty list
     * @drawable false
     */
    createEmptyList(): [];
    /**
     * Repeat the item and add it in the new list
     * @param inputs an item to multiply
     * @returns list
     * @group create
     * @shortname repeat
     * @drawable false
     */
    repeat(inputs: Inputs.Lists.MultiplyItemDto): any;
}
