import * as Inputs from '../inputs/inputs';
/**
 * Contains various math methods.
 * <div>
 *  <img src="../assets/images/blockly-images/math/math.svg" alt="Blockly Image"/>
 * </div>
 */
export declare class MathBitByBit {
    constructor();
    /**
     * Creates a number
     * @param inputs a number to be created
     * @returns number
     * @group create
     * @shortname number
     * @drawable false
     */
    number(inputs: Inputs.Math.NumberDto): number;
    /**
     * Does basic math operations
     * @param inputs two numbers and operator
     * @returns Result of math operation action
     * @group operations
     * @shortname two numbers
     * @drawable false
     */
    twoNrOperation(inputs: Inputs.Math.ActionOnTwoNumbersDto): number;
    /**
     * Does basic math operations on one number
     * @param inputs one number and operator action
     * @returns Result of math operation
     * @group operations
     * @shortname one number
     * @drawable false
     */
    oneNrOperation(inputs: Inputs.Math.ActionOnOneNumberDto): number;
    /**
    * Remaps a number from one range to another
    * @param inputs one number and operator action
    * @returns Result of mapping
    * @group operations
    * @shortname remap
    * @drawable false
    */
    remap(inputs: Inputs.Math.RemapNumberDto): number;
    /**
    * Creates a random number between low and high value
    * @param inputs low and high numbers
    * @returns A random number
    * @group generate
    * @shortname random number
    * @drawable false
    */
    randomNumber(inputs: Inputs.Math.RandomNumberDto): number;
    /**
    * Creates random numbers between low and high values
    * @param inputs low and high numbers
    * @returns A list of random numbers
    * @group generate
    * @shortname random numbers
    * @drawable false
    */
    randomNumbers(inputs: Inputs.Math.RandomNumbersDto): number[];
    /**
    * Creates a PI number
    * @returns A number PI
    * @group generate
    * @shortname π
    * @drawable false
    */
    pi(): number;
}
