var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { MathBitByBit } from './math';
import * as Inputs from '../inputs/inputs';
describe('Math unit tests', () => {
    let math;
    beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
        math = new MathBitByBit();
    }));
    it('should create number', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.number({ number: 1 });
        expect(result).toEqual(1);
    }));
    it('should perform addition', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.twoNrOperation({ first: 1, second: 2, operation: Inputs.Math.MathTwoNrOperatorEnum.add });
        expect(result).toEqual(3);
    }));
    it('should perform subtraction', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.twoNrOperation({ first: 1, second: 2, operation: Inputs.Math.MathTwoNrOperatorEnum.subtract });
        expect(result).toEqual(-1);
    }));
    it('should perform multiplication', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.twoNrOperation({ first: 1, second: 2, operation: Inputs.Math.MathTwoNrOperatorEnum.multiply });
        expect(result).toEqual(2);
    }));
    it('should perform division', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.twoNrOperation({ first: 1, second: 2, operation: Inputs.Math.MathTwoNrOperatorEnum.divide });
        expect(result).toEqual(0.5);
    }));
    it('should perform modulus', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.twoNrOperation({ first: 1, second: 2, operation: Inputs.Math.MathTwoNrOperatorEnum.modulus });
        expect(result).toEqual(1);
    }));
    it('should perform power', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.twoNrOperation({ first: 2, second: 3, operation: Inputs.Math.MathTwoNrOperatorEnum.power });
        expect(result).toEqual(8);
    }));
    it('should perform square root', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 4, operation: Inputs.Math.MathOneNrOperatorEnum.sqrt });
        expect(result).toEqual(2);
    }));
    it('should perform absolute', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: -4, operation: Inputs.Math.MathOneNrOperatorEnum.absolute });
        expect(result).toEqual(4);
    }));
    it('should perform round', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 4.5, operation: Inputs.Math.MathOneNrOperatorEnum.round });
        expect(result).toEqual(5);
    }));
    it('should perform floor', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 4.5, operation: Inputs.Math.MathOneNrOperatorEnum.floor });
        expect(result).toEqual(4);
    }));
    it('should perform ceiling', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 4.5, operation: Inputs.Math.MathOneNrOperatorEnum.ceil });
        expect(result).toEqual(5);
    }));
    it('should perform negate', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 4, operation: Inputs.Math.MathOneNrOperatorEnum.negate });
        expect(result).toEqual(-4);
    }));
    it('should perform natural logarithm', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 4, operation: Inputs.Math.MathOneNrOperatorEnum.ln });
        expect(result).toEqual(1.3862943611198906);
    }));
    it('should perform log base 10', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 100, operation: Inputs.Math.MathOneNrOperatorEnum.log10 });
        expect(result).toEqual(2);
    }));
    it('should perform 10 to the power', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 2, operation: Inputs.Math.MathOneNrOperatorEnum.tenPow });
        expect(result).toEqual(100);
    }));
    it('should perform sine', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 90, operation: Inputs.Math.MathOneNrOperatorEnum.sin });
        expect(result).toEqual(0.8939966636005579);
    }));
    it('should perform cosine', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 90, operation: Inputs.Math.MathOneNrOperatorEnum.cos });
        expect(result).toEqual(-0.4480736161291702);
    }));
    it('should perform tangent', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 90, operation: Inputs.Math.MathOneNrOperatorEnum.tan });
        expect(result).toEqual(-1.995200412208242);
    }));
    it('should perform arcsine', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.oneNrOperation({ number: 0.5, operation: Inputs.Math.MathOneNrOperatorEnum.asin });
        expect(result).toEqual(0.5235987755982989);
    }));
    it('should remap a number', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = math.remap({ number: 0.5, fromLow: 0, fromHigh: 1, toLow: 0, toHigh: 10 });
        expect(result).toEqual(5);
    }));
});
