var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as Inputs from '../../inputs/inputs';
import { OCCTIO } from 'bitbybit-occt-worker';
import { BitByBitContextHelperService } from '../../../bit-by-bit-context-helper.service';
import { STLExport } from '@babylonjs/serializers';
export class OCCTWIO extends OCCTIO {
    constructor(occWorkerManager, geometryHelper) {
        super(occWorkerManager);
        this.occWorkerManager = occWorkerManager;
        this.geometryHelper = geometryHelper;
    }
    /**
     * Imports the step or iges asset file
     * @param inputs STEP or IGES import
     * @group io
     * @shortname load step | iges
     * @returns OCCT Shape
     */
    loadSTEPorIGES(inputs) {
        // first we should check if we have assetName loaded already
        // if we dont have we do this, otherwise return from the cache...
        return BitByBitContextHelperService.getFile(inputs.assetFile).then(s => {
            return this.occWorkerManager.genericCallToWorkerPromise('io.loadSTEPorIGES', new Inputs.OCCT.LoadStepOrIgesDto(s, inputs.assetFile.name, inputs.adjustZtoY));
        });
    }
    /**
     * Saves the stl file
     * @param inputs STL filename and shape to be saved
     * @group io
     * @shortname save stl
     * @returns String of a stl file
     */
    saveShapeStl(inputs) {
        return __awaiter(this, void 0, void 0, function* () {
            const inp = new Inputs.OCCT.DrawShapeDto();
            inp.drawEdges = false;
            inp.shape = inputs.shape;
            inp.precision = inputs.precision;
            const fe = yield this.occWorkerManager.genericCallToWorkerPromise('shapeToMesh', inp);
            let dummy;
            const faceMeshes = fe.faceList.map(face => {
                const mesh = this.geometryHelper.createOrUpdateSurfaceMesh({
                    positions: face.vertex_coord,
                    normals: face.normal_coord,
                    indices: face.tri_indexes,
                }, dummy, false, undefined, true, false);
                return mesh;
            });
            STLExport.CreateSTL(faceMeshes, true, inputs.filename, true, true, true);
            faceMeshes.forEach(fm => fm.dispose());
            return fe;
        });
    }
}
