import { Mesh } from '@babylonjs/core';
import { Context } from '../../context';
import { GeometryHelper } from '../../geometry-helper';
import * as Inputs from '../../inputs/inputs';
import { JSCADText } from '../jscad/text';
import { Vector } from '../vector';
import { OCCTWIO } from './io';
import { OCCTWorkerManager, OCCT } from 'bitbybit-occt-worker';
/**
 * Contains various methods for OpenCascade implementation
 */
export declare class OCCTW extends OCCT {
    private readonly context;
    readonly occWorkerManager: OCCTWorkerManager;
    private readonly geometryHelper;
    private readonly solidText;
    private readonly vector;
    readonly io: OCCTWIO;
    constructor(context: Context, occWorkerManager: OCCTWorkerManager, geometryHelper: GeometryHelper, solidText: JSCADText, vector: Vector);
    /**
     * Draws OpenCascade shape by going through faces and edges
     * @param inputs Contains a shape to be drawn and additional information
     * @returns BabylonJS Mesh
     * @group drawing
     * @shortname draw shape
     * @drawable false
     * @ignore true
     */
    drawShape(inputs: Inputs.OCCT.DrawShapeDto<Inputs.OCCT.TopoDSShapePointer>): Promise<Mesh>;
    private computeFaceMiddlePos;
    private computeEdgeMiddlePos;
}
