/**
 * Conical surface functions.
 * These functions wrap around Verbnurbs library that you can find here http://verbnurbs.com/.
 * Thanks Peter Boyer for his work.
 */
export class VerbSurfaceConical {
    constructor(context) {
        this.context = context;
    }
    /**
     * Creates the conical Nurbs surface
     * @param inputs Parameters for Nurbs conical surface
     * @returns Conical Nurbs surface
     */
    create(inputs) {
        return new this.context.verb.geom.ConicalSurface(inputs.axis, inputs.xAxis, inputs.base, inputs.height, inputs.radius);
    }
    /**
     * Get cone axis
     * @param inputs Nurbs conical surface
     * @returns Axis vector
     */
    axis(inputs) {
        return inputs.cone.axis();
    }
    /**
     * Get cone base
     * @param inputs Nurbs conical surface
     * @returns Base point
     */
    base(inputs) {
        return inputs.cone.base();
    }
    /**
     * Get cone height
     * @param inputs Nurbs conical surface
     * @returns Height
     */
    height(inputs) {
        return inputs.cone.height();
    }
    /**
     * Get cone radius
     * @param inputs Nurbs conical surface
     * @returns Radius
     */
    radius(inputs) {
        return inputs.cone.radius();
    }
    /**
     * Get cone x axis
     * @param inputs Nurbs conical surface
     * @returns X axis vector
     */
    xAxis(inputs) {
        return inputs.cone.xaxis();
    }
}
