/**
 * Cylindrical surface functions.
 * These functions wrap around Verbnurbs library that you can find here http://verbnurbs.com/.
 * Thanks Peter Boyer for his work.
 */
export class VerbSurfaceCylindrical {
    constructor(context) {
        this.context = context;
    }
    /**
     * Creates the cylindrical Nurbs surface
     * @param inputs Parameters for cylindrical Nurbs surface
     * @returns Cylindrical Nurbs surface
     */
    create(inputs) {
        return new this.context.verb.geom.CylindricalSurface(inputs.axis, inputs.xAxis, inputs.base, inputs.height, inputs.radius);
    }
    /**
     * Get cylinder axis
     * @param inputs Nurbs cylindrical surface
     * @returns Axis vector
     */
    axis(inputs) {
        return inputs.cylinder.axis();
    }
    /**
     * Get cylinder base
     * @param inputs Nurbs cylindrical surface
     * @returns Base point
     */
    base(inputs) {
        return inputs.cylinder.base();
    }
    /**
     * Get cylinder height
     * @param inputs Nurbs cylindrical surface
     * @returns Height
     */
    height(inputs) {
        return inputs.cylinder.height();
    }
    /**
     * Get cylinder radius
     * @param inputs Nurbs cylindrical surface
     * @returns Radius
     */
    radius(inputs) {
        return inputs.cylinder.radius();
    }
    /**
     * Get cylinder x axis
     * @param inputs Nurbs cylindrical surface
     * @returns X axis vector
     */
    xAxis(inputs) {
        return inputs.cylinder.xaxis();
    }
}
