// tslint:disable-next-line: no-namespace
export var Draw;
(function (Draw) {
    class DrawAny {
    }
    Draw.DrawAny = DrawAny;
    class SceneDrawGridMeshDto {
        constructor() {
            /**
             * Width of the grid
             * @default 400
             * @minimum 0
             * @maximum Infinity
             * @step 10
             */
            this.width = 400;
            /**
             * Height of the ground
             * @default 400
             * @minimum 0
             * @maximum Infinity
             * @step 10
             */
            this.height = 400;
            /**
             * Ground subdivisions
             * @default 10
             * @minimum 0
             * @maximum Infinity
             * @step 1
             */
            this.subdivisions = 10;
            /**
             * The frequency of thicker lines.
             * @default 10
             * @minimum 0
             * @maximum Infinity
             * @step 1
             */
            this.majorUnitFrequency = 10;
            /**
             * The visibility of minor units in the grid.
             * @default 0.45
             * @minimum 0
             * @maximum 1
             * @step 0.1
             */
            this.minorUnitVisibility = 0.45;
            /**
             * The scale of the grid compared to unit.
             * @default 0.5
             * @minimum 0
             * @maximum Infinity
             * @step 0.1
             */
            this.gridRatio = 0.5;
            /**
             * The grid opacity outside of the lines.
             * @default 0.5
             * @minimum 0
             * @maximum 1
             * @step 0.1
             */
            this.opacity = 0.5;
            /**
             * Cull the back faces
             * @default false
             */
            this.backFaceCulling = false;
            /**
             * Main color of the grid (e.g. between lines)
             * @default #ffffff
             */
            this.mainColor = '#ffffff';
            /**
             * Color of the grid lines.
             * @default #ffffff
             */
            this.secondaryColor = '#ffffff';
        }
    }
    Draw.SceneDrawGridMeshDto = SceneDrawGridMeshDto;
    /**
     * Draw options for basic geometry types like points, lines, polylines, surfaces and jscad meshes
     */
    class DrawBasicGeometryOptions {
        constructor() {
            /**
             * Basic geometry colours to use for lines, points, polylines, surfaces, jscad meshes.
             * @default #ff0000
             */
            this.colours = '#ff0000';
            /**
             * Size affect how big the drawn points are and how wide lines are.
             * @default 3
             * @minimum 0
             * @maximum Infinity
             * @step 0.1
             */
            this.size = 3;
            /**
             * Opacity of the point 0 to 1
             * @default 1
             * @minimum 0
             * @maximum 1
             * @step 0.1
             */
            this.opacity = 1;
            /**
             * If geometry needs to be updated later
             * @default false
             */
            this.updatable = false;
            /**
             * Hidden
             * @default false
             */
            this.hidden = false;
        }
    }
    Draw.DrawBasicGeometryOptions = DrawBasicGeometryOptions;
    /**
     * Draw options for Nodes
     */
    class DrawNodeOptions {
        constructor() {
            /**
             * X Axis colour
             * @default #ff0000
             */
            this.colorX = '#0000ff';
            /**
             * Y Axis colour
             * @default #00ff00
             */
            this.colorY = '#00ff00';
            /**
             * Z Axis colour
             * @default #0000ff
             */
            this.colorZ = '#ff0000';
            /**
             * Length of the node axis
             * @default 2
             * @minimum 0
             * @maximum Infinity
             */
            this.size = 2;
        }
    }
    Draw.DrawNodeOptions = DrawNodeOptions;
    /**
     * Draw options for OCCT shapes
     */
    class DrawOcctShapeOptions {
        constructor() {
            /**
             * Face opacity value between 0 and 1
             * @default 1
             * @minimum 0
             * @maximum Infinity
             *
             */
            this.faceOpacity = 1;
            /**
             * Edge opacity value between 0 and 1
             * @default 1
             * @minimum 0
             * @maximum 1
             */
            this.edgeOpacity = 1;
            /**
             * Hex colour string for the edges
             * @default #ffffff
             */
            this.edgeColour = '#ffffff';
            /**
             * Hex colour string for face colour
             * @default #ff0000
             */
            this.faceColour = '#ff0000';
            /**
             * Edge width
             * @default 2
             * @minimum 0
             * @maximum Infinity
             */
            this.edgeWidth = 2;
            /**
             * You can turn off drawing of edges via this property
             * @default true
             */
            this.drawEdges = true;
            /**
             * You can turn off drawing of faces via this property
             * @default true
             */
            this.drawFaces = true;
            /**
             * Precision
             * @default 0.01
             * @minimum 0
             * @maximum Infinity
             */
            this.precision = 0.01;
            /**
             * Draw index of edges in space
             * @default false
             */
            this.drawEdgeIndexes = false;
            /**
             * Indicates the edge index height if they are drawn
             * @default 0.06
             * @minimum 0
             * @maximum Infinity
             */
            this.edgeIndexHeight = 0.06;
            /**
             * Edge index colour if the edges are drawn
             * @default ff00ff
             */
            this.edgeIndexColour = '#ff00ff';
            /**
             * Draw indexes of faces in space
             * @default false
             */
            this.drawFaceIndexes = false;
            /**
             * Indicates the edge index height if they are drawn
             * @default 0.06
             * @minimum 0
             * @maximum Infinity
             */
            this.faceIndexHeight = 0.06;
            /**
             * Edge index colour if the edges are drawn
             * @default #0000ff
             */
            this.faceIndexColour = '#0000ff';
        }
    }
    Draw.DrawOcctShapeOptions = DrawOcctShapeOptions;
    let drawingTypes;
    (function (drawingTypes) {
        drawingTypes[drawingTypes["point"] = 0] = "point";
        drawingTypes[drawingTypes["points"] = 1] = "points";
        drawingTypes[drawingTypes["line"] = 2] = "line";
        drawingTypes[drawingTypes["lines"] = 3] = "lines";
        drawingTypes[drawingTypes["node"] = 4] = "node";
        drawingTypes[drawingTypes["nodes"] = 5] = "nodes";
        drawingTypes[drawingTypes["polyline"] = 6] = "polyline";
        drawingTypes[drawingTypes["polylines"] = 7] = "polylines";
        drawingTypes[drawingTypes["verbCurve"] = 8] = "verbCurve";
        drawingTypes[drawingTypes["verbCurves"] = 9] = "verbCurves";
        drawingTypes[drawingTypes["verbSurface"] = 10] = "verbSurface";
        drawingTypes[drawingTypes["verbSurfaces"] = 11] = "verbSurfaces";
        drawingTypes[drawingTypes["jscadMesh"] = 12] = "jscadMesh";
        drawingTypes[drawingTypes["jscadMeshes"] = 13] = "jscadMeshes";
        drawingTypes[drawingTypes["occt"] = 14] = "occt";
        drawingTypes[drawingTypes["tag"] = 15] = "tag";
        drawingTypes[drawingTypes["tags"] = 16] = "tags";
    })(drawingTypes = Draw.drawingTypes || (Draw.drawingTypes = {}));
})(Draw || (Draw = {}));
