import { Angle } from '@babylonjs/core';
/**
 * Contains various functions for Solid extrusions from JSCAD library https://github.com/jscad/OpenJSCAD.org
 * Thanks JSCAD community for developing this kernel
 */
export class JSCADExtrusions {
    constructor(jscad, vecHelper) {
        this.jscad = jscad;
        this.vecHelper = vecHelper;
    }
    extrudeLinear(inputs) {
        const multipleGeometries = inputs.geometry.length && inputs.geometry.length > 0;
        const geometry = multipleGeometries ? inputs.geometry : [inputs.geometry];
        let extrusions = this.jscad.extrusions.extrudeLinear({
            height: inputs.height,
            twistAngle: Angle.FromDegrees(inputs.twistAngle).radians(),
            twistSteps: inputs.twistSteps
        }, ...geometry);
        if (multipleGeometries && !extrusions.length) {
            extrusions = [extrusions];
        }
        return extrusions;
    }
    extrudeRectangular(inputs) {
        const multipleGeometries = inputs.geometry.length && inputs.geometry.length > 0;
        const geometry = multipleGeometries ? inputs.geometry : [inputs.geometry];
        let extrusions = this.jscad.extrusions.extrudeRectangular({ height: inputs.height, size: inputs.size }, ...geometry);
        if (multipleGeometries && !extrusions.length) {
            extrusions = [extrusions];
        }
        return extrusions;
    }
    extrudeRectangularPoints(inputs) {
        const twoDimensionalPoints = inputs.points.map(pt => [pt[0], pt[1]]);
        const duplicatePointsRemoved = this.vecHelper.removeConsecutiveDuplicates(twoDimensionalPoints);
        const path = this.jscad.geometries.path2.fromPoints({}, duplicatePointsRemoved);
        const extrusion = this.extrudeRectangular({ height: inputs.height, size: inputs.size, geometry: path });
        return extrusion;
    }
    extrudeRotate(inputs) {
        const options = {
            angle: Angle.FromDegrees(inputs.angle).radians(),
            startAngle: Angle.FromDegrees(inputs.startAngle).radians(),
            overflow: 'cap',
            segments: inputs.segments
        };
        const extrusion = this.jscad.extrusions.extrudeRotate(options, inputs.polygon);
        return extrusion;
    }
}
